import numpy as np
import pandas as pd

def AAP(num_cv, num_repeat, file_name):
    """
    AAP calculates average activation potential of each selected feature
    based on k-fold (num_cv) cross validation using the weights between input features
    and the first hidden layer.
    :param num_cv: integer, the number of folds used in cross validation
    :param num_repeat: integer, the number of repeats of the experiment
    :param filename: string, the path to your data file
    :return: pandas series, AAP values
    """

    # Read the file with outputs from DNP
    file_ls = []

    with open(file_name, 'r') as f:
        for line in f:
            file_ls.append(line.strip())

    # select only lines start with 'feature'
    features = [line for line in file_ls if line[:7] == 'feature']

    # keep only the feature IDs and the positive contribution values
    feature_ids = [feature.split()[1] for feature in features]
    feature_weights = [feature.split()[-1] for feature in features]

    # Convert feature weights to pandas series
    feature_weights = np.array(feature_weights, dtype=np.float32)
    feature_weights = pd.Series(feature_weights, index=feature_ids)

    # convert from python list to pandas series to use unique() method
    feature_ids = pd.Series(feature_ids)

    # get a list of unique ID from fid
    # (repetative from k-fold cross validation and multiple repeats of the experiment)
    unique_id = feature_ids.unique()

    # calculate average activation potential AAP
    aap = []

    for id in unique_id:
        id_mean = feature_weights[id].sum() / (num_cv * num_repeat)
        aap.append(id_mean)

    aap = np.array(aap)
    aap = pd.Series(aap, index=unique_id)

    # sort the aap in descending order
    aap = aap.sort_values(ascending=False)

    return aap